{
    "$graph": [
        {
            "doc": "A wrapper for running `samtools index <bam>`.\n",
            "class": "CommandLineTool",
            "label": "run-index-bam",
            "baseCommand": [
                "samtools",
                "index"
            ],
            "requirements": [
                {
                    "dockerPull": "quay.io/biocontainers/samtools:1.8--4",
                    "class": "DockerRequirement"
                },
                {
                    "listing": [
                        "$(inputs.input_bam)"
                    ],
                    "class": "InitialWorkDirRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "valueFrom": "$(self.basename)"
                    },
                    "id": "#indexbam.cwl/input_bam"
                }
            ],
            "id": "#indexbam.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.basename)"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#indexbam.cwl/bam_index"
                }
            ]
        },
        {
            "doc": "A CWL wrapper for [run_MarkDuplicates.py](https://github.com/broadinstitute/gtex-pipeline/blob/master/rnaseq/src/run_MarkDuplicates.py)\n\nRuns [Picard](https://github.com/broadinstitute/picard) [MarkDuplicates](https://broadinstitute.github.io/picard/command-line-overview.html#MarkDuplicates)\n\nThis CWL Tool was developed as step 2 of the TOPMed RNA-seq workflow.\n",
            "class": "CommandLineTool",
            "label": "run-MarkDuplicates",
            "baseCommand": [
                "picard",
                "MarkDuplicates"
            ],
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/picard:2.9.2--2",
                    "class": "DockerRequirement"
                },
                {
                    "envDef": [
                        {
                            "envValue": "-Xmx$(runtime.ram)M",
                            "envName": "JAVA_TOOL_OPTIONS"
                        }
                    ],
                    "class": "EnvVarRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#markduplicates.cwl/input_bam"
                },
                {
                    "type": "string",
                    "id": "#markduplicates.cwl/prefix_str"
                }
            ],
            "arguments": [
                "I=$(inputs.input_bam.path)",
                "O=$(runtime.outdir)/$(inputs.input_bam.nameroot).md.bam",
                "M=$(runtime.outdir)/$(inputs.prefix_str).marked_dup_metrics.txt",
                "ASSUME_SORT_ORDER=coordinate",
                "OPTICAL_DUPLICATE_PIXEL_DISTANCE=100"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.nameroot).md.bam"
                    },
                    "id": "#markduplicates.cwl/bam_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.prefix_str).marked_dup_metrics.txt"
                    },
                    "id": "#markduplicates.cwl/metrics"
                }
            ],
            "id": "#markduplicates.cwl"
        },
        {
            "doc": "A CWL wrapper for [run_rnaseqc.py](https://github.com/heliumdatacommons/cwl_workflows/blob/master/topmed-workflows/TOPMed_RNAseq_pipeline/src/run_rnaseqc.py) duplicated from [run_rnaseqc.py](https://github.com/broadinstitute/gtex-pipeline/blob/master/rnaseq/src/run_rnaseqc.py) with minor modifications.\n\nRuns [RNA-SeQC 1.1.9](https://github.com/francois-a/rnaseqc)\n\nThis CWL Tool was developed as step 4 of the TOPMed RNA-seq workflow.\n",
            "class": "CommandLineTool",
            "label": "run-seqc",
            "baseCommand": [
                "python3",
                "/src/run_rnaseqc.py"
            ],
            "requirements": [
                {
                    "dockerPull": "heliumdatacommons/topmed-rnaseq:latest",
                    "class": "DockerRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#rna_seqc.cwl/bam_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#rna_seqc.cwl/genes_gtf"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#rna_seqc.cwl/genome_fasta"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#rna_seqc.cwl/prefix_str"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "itemSeparator": " "
                        }
                    },
                    "inputBinding": {
                        "position": 7,
                        "prefix": "--rnaseqc_flags"
                    },
                    "id": "#rna_seqc.cwl/rnaseqc_flags"
                }
            ],
            "arguments": [
                {
                    "prefix": "--memory",
                    "valueFrom": "$(runtime.ram / 1024)"
                },
                {
                    "prefix": "--java",
                    "valueFrom": "/usr/lib/jvm/java-1.7.0-openjdk-amd64/bin/java"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.metrics.tsv"
                    },
                    "id": "#rna_seqc.cwl/count_metrics"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.tar.gz"
                    },
                    "id": "#rna_seqc.cwl/count_outputs"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.exon_reads.gct.gz"
                    },
                    "id": "#rna_seqc.cwl/exon_counts"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.gene_reads.gct.gz"
                    },
                    "id": "#rna_seqc.cwl/gene_counts"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.gene_rpkm.gct.gz"
                    },
                    "id": "#rna_seqc.cwl/gene_rpkm"
                }
            ],
            "id": "#rna_seqc.cwl"
        },
        {
            "doc": "TOPMed RNA-seq CWL workflow. Documentation on the workflow can be found [here](https://github.com/heliumdatacommons/TOPMed_RNAseq_CWL/blob/master/README.md).\nExample input files: [Dockstore.json](https://github.com/heliumdatacommons/TOPMed_RNAseq_CWL/blob/master/workflow/input-examples/Dockstore.json) and [rnaseq_pipeline_fastq-example.yml](https://github.com/heliumdatacommons/TOPMed_RNAseq_CWL/blob/master/workflow/input-examples/rnaseq_pipeline_fastq-example.yml).\n\nQuickstart instructions are [here](https://github.com/heliumdatacommons/TOPMed_RNAseq_CWL/README.md#Quick Start).\n\n[GitHub Repo](https://github.com/heliumdatacommons/TOPMed_RNAseq_CWL)\n\nPipeline steps:\n1. Align RNA-seq reads with [STAR v2.5.3a](https://github.com/alexdobin/STAR).\n2. Run [Picard](https://github.com/broadinstitute/picard) [MarkDuplicates](https://broadinstitute.github.io/picard/command-line-overview.html#MarkDuplicates).\n2a. Create BAM index for MarkDuplicates BAM with [Samtools 1.6](https://github.com/samtools/samtools/releases) index.\n3. Transcript quantification with [RSEM 1.3.0](https://deweylab.github.io/RSEM/)\n4. Gene quantification and quality control with [RNA-SeQC 1.1.9](https://github.com/francois-a/rnaseqc)\n",
            "class": "Workflow",
            "label": "TOPMed_RNA-seq",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "id": "#main/estimate_rspd"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/fastqs"
                },
                {
                    "type": "File",
                    "id": "#main/genes_gtf"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#main/genome_fasta"
                },
                {
                    "type": "boolean",
                    "id": "#main/is_stranded"
                },
                {
                    "type": "int",
                    "id": "#main/max_frag_len"
                },
                {
                    "type": "boolean",
                    "id": "#main/paired_end"
                },
                {
                    "type": "string",
                    "id": "#main/prefix_str"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/rnaseqc_flags"
                },
                {
                    "type": "Directory",
                    "id": "#main/rsem_ref_dir"
                },
                {
                    "type": "Directory",
                    "id": "#main/star_index"
                }
            ],
            "outputs": [
                {
                    "outputSource": "#main/run_index_markduplicates_bam/bam_index",
                    "type": "File",
                    "id": "#main/markduplicates_bam_index"
                },
                {
                    "outputSource": "#main/run_markduplicates/bam_file",
                    "type": "File",
                    "id": "#main/markduplicates_output_bam"
                },
                {
                    "outputSource": "#main/run_markduplicates/metrics",
                    "type": "File",
                    "id": "#main/markduplicates_output_metrics"
                },
                {
                    "outputSource": "#main/run_rna-seqc/count_metrics",
                    "type": "File",
                    "id": "#main/rna-seqc_output_count_metrics"
                },
                {
                    "outputSource": "#main/run_rna-seqc/count_outputs",
                    "type": "File",
                    "id": "#main/rna-seqc_output_count_outputs"
                },
                {
                    "outputSource": "#main/run_rna-seqc/exon_counts",
                    "type": "File",
                    "id": "#main/rna-seqc_output_exon_counts"
                },
                {
                    "outputSource": "#main/run_rna-seqc/gene_counts",
                    "type": "File",
                    "id": "#main/rna-seqc_output_gene_counts"
                },
                {
                    "outputSource": "#main/run_rna-seqc/gene_rpkm",
                    "type": "File",
                    "id": "#main/rna-seqc_output_gene_rpkm"
                },
                {
                    "outputSource": "#main/run_rsem/gene_results",
                    "type": "File",
                    "id": "#main/rsem_output_gene_results"
                },
                {
                    "outputSource": "#main/run_rsem/isoforms_results",
                    "type": "File",
                    "id": "#main/rsem_output_isoforms_results"
                },
                {
                    "outputSource": "#main/sort_bam/output_file",
                    "type": "File",
                    "id": "#main/star_output_bam"
                },
                {
                    "outputSource": "#main/index_bam/bam_index",
                    "type": "File",
                    "id": "#main/star_output_bam_index"
                },
                {
                    "outputSource": "#main/sort_chimeras/output_file",
                    "type": "File",
                    "id": "#main/star_output_chimeric_bam_file"
                },
                {
                    "outputSource": "#main/index_chimeras/bam_index",
                    "type": "File",
                    "id": "#main/star_output_chimeric_bam_index"
                },
                {
                    "outputSource": "#main/run_star/chimeric_junctions",
                    "type": "File",
                    "id": "#main/star_output_chimeric_junctions"
                },
                {
                    "outputSource": "#main/run_star/junctions",
                    "type": "File",
                    "id": "#main/star_output_junctions"
                },
                {
                    "outputSource": "#main/run_star/junctions_pass1",
                    "type": "File",
                    "id": "#main/star_output_junctions_pass1"
                },
                {
                    "outputSource": "#main/run_star/logs",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/star_output_logs"
                },
                {
                    "outputSource": "#main/run_star/read_counts",
                    "type": "File",
                    "id": "#main/star_output_read_counts"
                },
                {
                    "outputSource": "#main/run_star/transcriptome_bam",
                    "type": "File",
                    "id": "#main/star_output_transcriptome_bam"
                }
            ],
            "steps": [
                {
                    "run": "#indexbam.cwl",
                    "in": [
                        {
                            "source": "#main/sort_bam/output_file",
                            "id": "#main/index_bam/input_bam"
                        }
                    ],
                    "out": [
                        "#main/index_bam/bam_index"
                    ],
                    "id": "#main/index_bam"
                },
                {
                    "run": "#indexbam.cwl",
                    "in": [
                        {
                            "source": "#main/sort_chimeras/output_file",
                            "id": "#main/index_chimeras/input_bam"
                        }
                    ],
                    "out": [
                        "#main/index_chimeras/bam_index"
                    ],
                    "id": "#main/index_chimeras"
                },
                {
                    "run": "#indexbam.cwl",
                    "in": [
                        {
                            "source": "#main/run_markduplicates/bam_file",
                            "id": "#main/run_index_markduplicates_bam/input_bam"
                        }
                    ],
                    "out": [
                        "#main/run_index_markduplicates_bam/bam_index"
                    ],
                    "id": "#main/run_index_markduplicates_bam"
                },
                {
                    "run": "#markduplicates.cwl",
                    "in": [
                        {
                            "source": "#main/sort_bam/output_file",
                            "id": "#main/run_markduplicates/input_bam"
                        },
                        {
                            "source": "#main/prefix_str",
                            "id": "#main/run_markduplicates/prefix_str"
                        }
                    ],
                    "out": [
                        "#main/run_markduplicates/bam_file",
                        "#main/run_markduplicates/metrics"
                    ],
                    "id": "#main/run_markduplicates"
                },
                {
                    "run": "#rna_seqc.cwl",
                    "in": [
                        {
                            "source": "#main/run_index_markduplicates_bam/bam_index",
                            "id": "#main/run_rna-seqc/bam_file"
                        },
                        {
                            "source": "#main/genes_gtf",
                            "id": "#main/run_rna-seqc/genes_gtf"
                        },
                        {
                            "source": "#main/genome_fasta",
                            "id": "#main/run_rna-seqc/genome_fasta"
                        },
                        {
                            "source": "#main/prefix_str",
                            "id": "#main/run_rna-seqc/prefix_str"
                        },
                        {
                            "source": "#main/rnaseqc_flags",
                            "id": "#main/run_rna-seqc/rnaseqc_flags"
                        }
                    ],
                    "out": [
                        "#main/run_rna-seqc/gene_rpkm",
                        "#main/run_rna-seqc/gene_counts",
                        "#main/run_rna-seqc/exon_counts",
                        "#main/run_rna-seqc/count_metrics",
                        "#main/run_rna-seqc/count_outputs"
                    ],
                    "id": "#main/run_rna-seqc"
                },
                {
                    "run": "#rsem.cwl",
                    "in": [
                        {
                            "source": "#main/estimate_rspd",
                            "id": "#main/run_rsem/estimate_rspd"
                        },
                        {
                            "source": "#main/is_stranded",
                            "id": "#main/run_rsem/is_stranded"
                        },
                        {
                            "source": "#main/max_frag_len",
                            "id": "#main/run_rsem/max_frag_len"
                        },
                        {
                            "source": "#main/paired_end",
                            "id": "#main/run_rsem/paired_end"
                        },
                        {
                            "source": "#main/prefix_str",
                            "id": "#main/run_rsem/prefix_str"
                        },
                        {
                            "source": "#main/rsem_ref_dir",
                            "id": "#main/run_rsem/rsem_ref_dir"
                        },
                        {
                            "source": "#main/run_star/transcriptome_bam",
                            "id": "#main/run_rsem/transcriptome_bam"
                        }
                    ],
                    "out": [
                        "#main/run_rsem/gene_results",
                        "#main/run_rsem/isoforms_results"
                    ],
                    "id": "#main/run_rsem"
                },
                {
                    "run": "#star.cwl",
                    "in": [
                        {
                            "source": "#main/fastqs",
                            "id": "#main/run_star/fastqs"
                        },
                        {
                            "source": "#main/prefix_str",
                            "id": "#main/run_star/prefix"
                        },
                        {
                            "source": "#main/star_index",
                            "id": "#main/run_star/star_index"
                        }
                    ],
                    "out": [
                        "#main/run_star/bam",
                        "#main/run_star/transcriptome_bam",
                        "#main/run_star/chimeric_junctions",
                        "#main/run_star/chimeric_bam",
                        "#main/run_star/read_counts",
                        "#main/run_star/junctions",
                        "#main/run_star/junctions_pass1",
                        "#main/run_star/logs"
                    ],
                    "id": "#main/run_star"
                },
                {
                    "run": "#samtools-sort.cwl",
                    "in": [
                        {
                            "source": "#main/run_star/bam",
                            "id": "#main/sort_bam/input"
                        },
                        {
                            "source": "#main/prefix_str",
                            "valueFrom": "$(self).Aligned.sortedByCoord.out.bam",
                            "id": "#main/sort_bam/output_name"
                        }
                    ],
                    "out": [
                        "#main/sort_bam/output_file"
                    ],
                    "id": "#main/sort_bam"
                },
                {
                    "run": "#samtools-sort.cwl",
                    "in": [
                        {
                            "source": "#main/run_star/chimeric_bam",
                            "id": "#main/sort_chimeras/input"
                        },
                        {
                            "source": "#main/prefix_str",
                            "valueFrom": "$(self).Chimeric.out.sorted.bam",
                            "id": "#main/sort_chimeras/output_name"
                        }
                    ],
                    "out": [
                        "#main/sort_chimeras/output_file"
                    ],
                    "id": "#main/sort_chimeras"
                }
            ],
            "id": "#main",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/id": "https://orcid.org/0000-0003-3523-5312",
                    "http://schema.org/email": "christopherball@rti.org",
                    "http://schema.org/name": "Christopher Ball"
                }
            ],
            "http://schema.org/codeRepository": "https://github.com/heliumdatacommons/cwl_workflows"
        },
        {
            "doc": "A CWL wrapper for [run_RSEM.py](https://github.com/broadinstitute/gtex-pipeline/blob/master/rnaseq/src/run_RSEM.py)\n\nRuns [RSEM 1.3.0](https://deweylab.github.io/RSEM/)\n\nThis CWL Tool was developed as step 3 of the TOPMed RNA-seq workflow.\n",
            "class": "CommandLineTool",
            "label": "run-rsem",
            "baseCommand": "rsem-calculate-expression",
            "requirements": [
                {
                    "listing": [
                        {
                            "entry": "$(inputs.rsem_ref_dir)",
                            "writable": true
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/rsem:1.3.0--boost1.64_3",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "--estimate-rspd"
                    },
                    "id": "#rsem.cwl/estimate_rspd"
                },
                {
                    "type": "boolean",
                    "id": "#rsem.cwl/is_stranded"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--fragment-length-max"
                    },
                    "id": "#rsem.cwl/max_frag_len"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "--paired-end"
                    },
                    "id": "#rsem.cwl/paired_end"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3,
                        "valueFrom": "$(self).rsem"
                    },
                    "id": "#rsem.cwl/prefix_str"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 2,
                        "valueFrom": "$(self.basename)/rsem_reference"
                    },
                    "id": "#rsem.cwl/rsem_ref_dir"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#rsem.cwl/transcriptome_bam"
                }
            ],
            "arguments": [
                {
                    "prefix": "--num-threads",
                    "valueFrom": "$(runtime.cores)"
                },
                {
                    "prefix": "--fragment-length-max",
                    "valueFrom": "1000"
                },
                "--no-bam-output",
                "--bam",
                "${if (inputs.is_stranded) { return [\"--forward-prob\", \"0.0\"];} }"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.prefix_str).rsem.genes.results"
                    },
                    "id": "#rsem.cwl/gene_results"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.prefix_str).rsem.isoforms.results"
                    },
                    "id": "#rsem.cwl/isoforms_results"
                }
            ],
            "id": "#rsem.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/cancercollaboratory/dockstore-tool-samtools-sort:1.0"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-l"
                    },
                    "doc": "Set compression level, from 0 (uncompressed) to 9 (best)",
                    "id": "#samtools-sort.cwl/compression_level"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "Input bam file.",
                    "id": "#samtools-sort.cwl/input"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-o"
                    },
                    "doc": "Desired output filename.",
                    "id": "#samtools-sort.cwl/output_name"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-n"
                    },
                    "doc": "Sort by read names (i.e., the QNAME field) rather than by chromosomal coordinates.",
                    "id": "#samtools-sort.cwl/sort_by_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name)"
                    },
                    "id": "#samtools-sort.cwl/output_file"
                }
            ],
            "arguments": [
                {
                    "prefix": "-@",
                    "valueFrom": "$(runtime.cores)"
                },
                {
                    "prefix": "-m",
                    "valueFrom": "$(runtime.ram)M"
                }
            ],
            "baseCommand": [
                "samtools",
                "sort"
            ],
            "doc": "Sort alignments by leftmost coordinates, or by read name when -n is used. An appropriate @HD-SO sort order header tag will be added or an existing one updated if necessary.\n\nUsage: samtools sort [-l level] [-m maxMem] [-o out.bam] [-O format] [-n] -T out.prefix [-@ threads] [in.bam]\n\nOptions:\n-l INT\nSet the desired compression level for the final output file, ranging from 0 (uncompressed) or 1 (fastest but minimal compression) to 9 (best compression but slowest to write), similarly to gzip(1)'s compression level setting.\n\nIf -l is not used, the default compression level will apply.\n\n\n-n\nSort by read names (i.e., the QNAME field) rather than by chromosomal coordinates.\n\n-o FILE\nWrite the final sorted output to FILE, rather than to standard output.\n\n-O FORMAT\nWrite the final output as sam, bam, or cram.\n\nBy default, samtools tries to select a format based on the -o filename extension; if output is to standard output or no format can be deduced, -O must be used.\n\n-T PREFIX\nWrite temporary files to PREFIX.nnnn.bam. This option is required.\n",
            "id": "#samtools-sort.cwl",
            "http://purl.org/dc/terms/contributor": {
                "foaf:name": "Andy Yang",
                "foaf:mbox": "mailto:ayang@oicr.on.ca"
            },
            "http://purl.org/dc/terms/creator": {
                "@id": "http://orcid.org/0000-0001-9102-5681",
                "foaf:name": "Andrey Kartashov",
                "foaf:mbox": "mailto:Andrey.Kartashov@cchmc.org"
            },
            "http://purl.org/dc/terms/description": "Developed at Cincinnati Children\u2019s Hospital Medical Center for the CWL consortium http://commonwl.org/ Original URL: https://github.com/common-workflow-language/workflows"
        },
        {
            "doc": "A CWL wrapper for [run_STAR.py](https://github.com/broadinstitute/gtex-pipeline/blob/master/rnaseq/src/run_STAR.py)\n\nRuns [STAR v2.5.3a](https://github.com/alexdobin/STAR)\n\nThis CWL Tool was developed as step 1 of the TOPMed RNA-seq workflow.\n",
            "class": "CommandLineTool",
            "label": "run-star",
            "baseCommand": "STAR",
            "hints": [
                {
                    "dockerFile": "FROM debian:buster-slim\nMAINTAINER biocontainers <biodocker@gmail.com>\nLABEL    software=\"rna-star\" \\\n    container=\"rna-star\" \\\n    about.summary=\"ultrafast universal RNA-seq aligner\" \\\n    about.home=\"https://github.com/alexdobin/STAR/\" \\\n    software.version=\"2.5.3adfsg-1-deb\" \\\n    version=\"1\" \\\n    about.copyright=\"2009-2015 Alexander Dobin <dobin@cshl.edu>\" \\\n    about.license=\"GPL-3+\" \\\n    about.license_file=\"/usr/share/doc/rna-star/copyright\" \\\n    extra.binaries=\"/usr/bin/STAR\" \\\n    about.tags=\"biology::nucleic-acids, field::biology, field::biology:bioinformatics,:c++, role::program, use::analysing,:biological-sequence\"\nENV DEBIAN_FRONTEND noninteractive\nRUN echo \\\n  'deb http://snapshot.debian.org/archive/debian/20170906/ buster  main' > /etc/apt/sources.list \\\n  && printf \"Package: r-*\\nPin: origin snapshot.debian.org\\nPin-Priority: 990\\n\" > /etc/apt/preferences.d/snapshot \\\n  && apt-get -o Acquire::Check-Valid-Until=false update \\\n  && apt-get upgrade -y \\\n  && apt-get install -y --no-install-recommends \\\n      --allow-unauthenticated rna-star=2.5.3a+dfsg-3 \\\n  && apt-get clean && apt-get purge && rm -rf /var/lib/apt/lists/* /tmp/*\n",
                    "dockerImageId": "star",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "itemSeparator": ","
                        }
                    },
                    "inputBinding": {
                        "prefix": "--readFilesIn"
                    },
                    "id": "#star.cwl/fastqs"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--outFileNamePrefix",
                        "valueFrom": "$(runtime.outdir)/$(self)."
                    },
                    "id": "#star.cwl/prefix"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "--genomeDir"
                    },
                    "id": "#star.cwl/star_index"
                }
            ],
            "arguments": [
                {
                    "prefix": "--runMode",
                    "valueFrom": "alignReads"
                },
                {
                    "prefix": "--runThreadN",
                    "valueFrom": "$(runtime.cores)"
                },
                {
                    "prefix": "--twopassMode",
                    "valueFrom": "Basic"
                },
                {
                    "prefix": "--outFilterMultimapNmax",
                    "valueFrom": "20"
                },
                {
                    "prefix": "--alignSJoverhangMin",
                    "valueFrom": "8"
                },
                {
                    "prefix": "--alignSJDBoverhangMin",
                    "valueFrom": "1"
                },
                {
                    "prefix": "--outFilterMismatchNmax",
                    "valueFrom": "999"
                },
                {
                    "prefix": "--outFilterMismatchNoverLmax",
                    "valueFrom": "0.1"
                },
                {
                    "prefix": "--alignIntronMin",
                    "valueFrom": "20"
                },
                {
                    "prefix": "--alignIntronMax",
                    "valueFrom": "1000000"
                },
                {
                    "prefix": "--alignMatesGapMax",
                    "valueFrom": "1000000"
                },
                {
                    "prefix": "--outFilterType",
                    "valueFrom": "BySJout"
                },
                {
                    "prefix": "--outFilterScoreMinOverLread",
                    "valueFrom": "0.33"
                },
                {
                    "prefix": "--outFilterMatchNminOverLread",
                    "valueFrom": "0.33"
                },
                {
                    "prefix": "--limitSjdbInsertNsj",
                    "valueFrom": "1200000"
                },
                {
                    "prefix": "--readFilesCommand",
                    "valueFrom": "zcat"
                },
                {
                    "prefix": "--outSAMstrandField",
                    "valueFrom": "introMotif"
                },
                {
                    "prefix": "--outFilterIntronMotifs",
                    "valueFrom": "None"
                },
                {
                    "prefix": "--alignSoftClipAtReferenceEnds",
                    "valueFrom": "Yes"
                },
                "--quantMode",
                "TranscriptomeSAM",
                "GeneCounts",
                "--outSAMtype",
                "BAM",
                "Unsorted",
                {
                    "prefix": "--outSAMunmapped",
                    "valueFrom": "Within"
                },
                {
                    "prefix": "--genomeLoad",
                    "valueFrom": "NoSharedMemory"
                },
                {
                    "prefix": "--chimSegmentMin",
                    "valueFrom": "15"
                },
                {
                    "prefix": "--chimJunctionOverhangMin",
                    "valueFrom": "15"
                },
                "--chimOutType",
                "WithinBAM",
                "SoftClip",
                {
                    "prefix": "--chimMainSegmentMultNmax",
                    "valueFrom": "1"
                },
                "--outSAMattributes",
                "NH",
                "HI",
                "AS",
                "nM",
                "NM",
                "ch",
                "--outSAMattrRGline",
                "ID:rg1",
                "SM:sm1"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.prefix).Aligned.out.bam"
                    },
                    "id": "#star.cwl/bam"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.prefix).Chimeric.out.sam"
                    },
                    "id": "#star.cwl/chimeric_bam"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.Chimeric.out.junction"
                    },
                    "id": "#star.cwl/chimeric_junctions"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.SJ.out.tab"
                    },
                    "id": "#star.cwl/junctions"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*._STARpass1/SJ.out.tab"
                    },
                    "id": "#star.cwl/junctions_pass1"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.*.out"
                    },
                    "id": "#star.cwl/logs"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.ReadsPerGene.out.tab"
                    },
                    "id": "#star.cwl/read_counts"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.Aligned.toTranscriptome.out.bam"
                    },
                    "id": "#star.cwl/transcriptome_bam"
                }
            ],
            "id": "#star.cwl"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://dublincore.org/2012/06/14/dcterms.rdf",
        "https://schema.org/docs/schema_org_rdfa.html",
        "http://xmlns.com/foaf/spec/20140114.rdf"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
